#!/usr/bin/env python
# -*- coding: utf-8  -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2012 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################

"""
Living Naturally Suppliers
"""

import csv

from rattail.core import Object


suppliers = None


def init(config):
    """
    Parses the local ``'SupplierList.csv'`` file and caches the results.
    """

    global suppliers

    csv_path = config.require('rattail.sw.livnat', 'suppliers.csv_file')
    suppliers = parse_supplier_list(csv_path)


class SupplierRecord(Object):
    """
    Represents a record as parsed from a ``'SupplierList.csv'`` file.
    """

    id = None
    name = None
    city = None
    state = None
    product_count = None


def find_supplier(name):
    """
    Looks for a :class:`SupplierRecord` instance named ``name`` and if found,
    returns it.
    """

    for supplier in suppliers:
        if supplier.name == name:
            return supplier
    return None


def parse_supplier_list(csv_path):
    """
    Parses a ``'SupplierList.csv'`` file (as obtained from Living Naturally's
    `POS Partner Website <http://pos.livingnaturally.com/>`_), and returns a
    list of :class:`SupplierRecord` instances contained within it.

    To obtain a copy of the ``'SupplierList.csv'`` file, follow the above link,
    then click on **POS Interface Specifications**, then **Download Living
    Naturally Suppliers**.
    """

    csv_file = open(csv_path, 'rb')
    reader = csv.reader(csv_file)
    records = []

    for line, row in enumerate(reader, 1):
        if line == 1:
            if row != ['SupplierID','Supplier','City','State','Products']:
                raise UnexpectedDataFormat(csv_path, 1)

        else: # line > 1; data record

            rec = SupplierRecord()
            rec.id = int(row[0])
            rec.name = row[1]
            rec.city = row[2].strip() # found one with way too much trailing space...
            rec.state = row[3]
            rec.product_count = int(row[4])
            records.append(rec)

    csv_file.close()
    return records
